==> haskell-asn1-encoding-0.9.6-151-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 asn1-encoding
version:              0.9.6
visibility:           public
id:                   asn1-encoding-0.9.6-4Mr8lfAgm3vLGtUfn31uGv
key:                  asn1-encoding-0.9.6-4Mr8lfAgm3vLGtUfn31uGv
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-asn1
synopsis:             ASN1 data reader and writer in RAW, BER and DER forms
description:
    ASN1 data reader and writer in raw form with supports for high level forms of ASN1 (BER, and DER).

category:             Data
abi:                  e967daec40b9ba73fd0400236bb8c0b4
exposed:              True
exposed-modules:
    Data.ASN1.BinaryEncoding Data.ASN1.BinaryEncoding.Raw
    Data.ASN1.Encoding Data.ASN1.Error Data.ASN1.Object Data.ASN1.Prim
    Data.ASN1.Stream

hidden-modules:
    Data.ASN1.BinaryEncoding.Parse Data.ASN1.BinaryEncoding.Writer
    Data.ASN1.Internal Data.ASN1.Serialize Data.ASN1.Get

import-dirs:          /usr/lib/ghc-9.0.2/site-local/asn1-encoding-0.9.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/asn1-encoding-0.9.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/asn1-encoding-0.9.6
hs-libraries:         HSasn1-encoding-0.9.6-4Mr8lfAgm3vLGtUfn31uGv
depends:
    asn1-types-0.3.4-7yKnuHE7MQB47GAssND8q0 base-4.15.1.0
    bytestring-0.10.12.1 hourglass-0.2.12-IaMrfa6GM8D9J0oQhk77ks

haddock-interfaces:
    /usr/share/doc/haskell-asn1-encoding/html/asn1-encoding.haddock

haddock-html:         /usr/share/doc/haskell-asn1-encoding/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-encoding-0.9.6-152-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-encoding.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 asn1-encoding
version:              0.9.6
visibility:           public
id:                   asn1-encoding-0.9.6-GnT2NuHu6iIEmiYrIoIdz3
key:                  asn1-encoding-0.9.6-GnT2NuHu6iIEmiYrIoIdz3
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/vincenthz/hs-asn1
synopsis:             ASN1 data reader and writer in RAW, BER and DER forms
description:
    ASN1 data reader and writer in raw form with supports for high level forms of ASN1 (BER, and DER).

category:             Data
abi:                  6ba8ba34ec9048620eafa27de419d1f3
exposed:              True
exposed-modules:
    Data.ASN1.BinaryEncoding Data.ASN1.BinaryEncoding.Raw
    Data.ASN1.Encoding Data.ASN1.Error Data.ASN1.Object Data.ASN1.Prim
    Data.ASN1.Stream

hidden-modules:
    Data.ASN1.BinaryEncoding.Parse Data.ASN1.BinaryEncoding.Writer
    Data.ASN1.Internal Data.ASN1.Serialize Data.ASN1.Get

import-dirs:          /usr/lib/ghc-9.0.2/site-local/asn1-encoding-0.9.6
library-dirs:         /usr/lib/ghc-9.0.2/site-local/asn1-encoding-0.9.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/asn1-encoding-0.9.6
hs-libraries:         HSasn1-encoding-0.9.6-GnT2NuHu6iIEmiYrIoIdz3
depends:
    asn1-types-0.3.4-8CDkSTdyLMVGovcmZhLOm0 base-4.15.1.0
    bytestring-0.10.12.1 hourglass-0.2.12-ESXwhILnfhY6X6UGsuXhG7

haddock-interfaces:
    /usr/share/doc/haskell-asn1-encoding/html/asn1-encoding.haddock

haddock-html:         /usr/share/doc/haskell-asn1-encoding/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
